
# Charm for IBM Java 1.8.0

### Overview

IBM Java

The IBM implementation of the Java platform provides a development toolkit and
an application runtime environment.

IBM supply two installable packages depending on platform: The Software
Developers Kit (SDK) and the Java Runtime Environment (JRE). The key components
in this charm are

- IBM Software Developers Kit (SDK) - The SDK contains development tools and a
    Java Runtime Environment (JRE).
- Runtime Environment - The Java runtime environment (JRE) provides runtime
    support for Java applications.
- J9 Virtual Machine (JVM) - The IBM J9 virtual machine (JVM) is the
    platform-specific component that runs a Java program.

User guides and security guides to support this release are available for
Online viewing [User Guide](http://www.ibm.com/support/knowledgecenter/SSYKE2_8.0.0/welcome/welcome_javasdk_version.html)

Any late breaking news can be found in the following
[IBM support technote](http://www.ibm.com/support/docview.wss?uid=swg21672834)

### Download of Product Binaries 

Download your licensed IBM Java 1.8.0 software for Ubuntu.

You can download product binaries from
[IBM developerWorks](https://www.ibm.com/developerworks/java/jdk/index.html)


#### Usage

To install the downloaded binaries you must agree to the IBM license.

IBM Java is a subordinate charm that can be related to any existing services
which consumes IBM Java as this charm relates via java interface.

Run the following to deploy this charm:

	juju deploy ibm-java

Here is the simple deployment scenario wherein IBM Java being installed on the ubuntu-devenv unit:

	juju deploy cs:~kwmonroe/trusty/ubuntu-devenv
	juju add-relation ubuntu-devenv ibm-java

In the above deployment scenario ubuntu-devenv and ibm-java charms are related via java interface.

At this point the charm will wait until the user accepts the license. If you
agree to the license, run the following command:

Set all required config values like the SFTP server,  package name, directory 
in SFTP server where package is kept, username and password to connect to 
SFTP host and checksum value to proceed with installation, by using 
juju set command. To provide these run the following command: 

	juju set ibm-java accept-ibm-java-license=True

If not,

	juju set ibm-java accept-ibm-java-license=True \
        host=<Web server host name> \
        package_dir=<Fully qualified Package path, do not add the package name > \
        username=<User name of the repository host> \
        password=<Password of the repository host> \
        javasdk_file_name=<IBM Java Package name> \
        javasdk_path_name=<IBM Java target Installation Directory> \
        java-major=<IBM Java Major version of java> \
        install-type=<IBM Java type of install to perform. Valid options are 'jre' or 'full'>


Once deployed, you can use IBM Java to run any Java workloads. To verify java is installed or not 
get into the containter where IBM Java is installed and run the below command.

	java -version

To get into the container run the below commmand.

	juju ssh <machine-id where IBM Java is installed>


### Uninstallation of ibm-java

Setting the accept-ibm-java-license to False will uninstall the product. 

	juju set ibm-java accept-ibm-java-license=False


### Configuration

- **accept-ibm-java-license** Before you can use or install IBM Java,
    you must accept the terms of International License
    Agreement for Non-Warranted Programs and additional license information.
    Please read the license agreement carefully
   [IBM Java SDK License](http://www-03.ibm.com/software/sla/sladb.nsf/displaylis/B0D11A46C1BE8BB585257E3B00660B2C?OpenDocument). Set the value of accept-ibm-java-license to True if you agree to IBM Java license.

**The IBM Java software cannot be installed until the terms and
conditions are accepted.  The charm will not function correctly until the
this configuration option is set to True.**

- **host** The web server host name from which IBM Java SDK installation packages 
    can be downloaded.

- **package_dir** The package directory path in the web server.

- **username** User name of the webserver host.

- **password** Password of the webserver host.

- **java_file_name** The IBM Java Package name. If not set, it is
    assigned to the default package name for power or x86_64 based machine.

- **java_path_name** The IBM Java SDK target installation directory. If not
    set, it will be assigned to the default value "/opt/ibm/java".

- **sha** Checksum value to check integrity of IBM Java package. The Charm
    uses sha1sum to check the integrity. If empty, it does not carry out the
    integrity check. Use `sha1sum <Package Location/Package Name> | cut -d" " -f1`
    to find out Checksum value for downloaded package. Cryptographic value
    should be altered by the user only when the package name is change. Else it
    should not be altered.

- **java-major** Major version of Java. If not
    set, it will be assigned to the default value 1.8.0.

- **install-type** Type of install to perform. Valid options are 'jre' or 'full'. 
    The default is 'jre', which will install the IBM Java Runtime Environment (JRE). 
    Setting this to 'full' will install the IBM Java Development Kit in addition to the JRE.

### IBM Java Information

### General Information

Details about IBM Java available [Here](http://www.ibm.com/support/knowledgecenter/SSYKE2_8.0.0/welcome/welcome_javasdk_version.html)

### Download Information

Information on procuring IBM Java product is available at the [Product Page](http://www.ibm.com/developerworks/java/jdk/linux/download.html)

A development version IBM Java is available [Here](http://www.ibm.com/software/products/en/mobilefirstfoundation)

### License Information

License information for IBM Java can be viewed [Here](http://www-03.ibm.com/software/sla/sladb.nsf/displaylis/B0D11A46C1BE8BB585257E3B00660B2C?OpenDocument)

### Known Limitations

This charm makes use of Juju Status commands, and requires juju 1.24 or greater

### Contact Information

For issues with this charm, please contact [IBM Juju Support Team](mailto:jujusupp@us.ibm.com)
